;This procedure is intended for use as part of the PCIAS system.  This system
;has been developed by the HAO dPMon project to facilitate the initial
;quality assurance procedures required for new dPmon data.  Please make
;no changes to any of the files in this directory without first contacting
;dPMon personnel.
;
;   Questions regarding PCIAS should be directed to:
;
;			Ray Wrigley     FL2 3084  x1588
;			Alice Lecinski  FL2 3037  x1523
;
;   The purpose of this module is to sort through the directory where
;   the current day's data is stored and sort the filenames into arrays
;   of strings, each of  which contain all the filenames of one type of
;   image (e.g. lowk, limb, etc.).   Also, this is a convenient time to
;   set up string arrays and such for the log file entry process.
;
pro pcias_filesort
@pcias_common

print,'correct version!'
;070830 changing next line to get around 'ls' list size limitation
;spawn, '(cd ' + topdir + dataday + '; /bin/ls -1 *.f*ts)', files
;to these lines:
spawn, 'pwd', curdir
cd, topdir+dataday
files = findfile('*.f*ts', count=ct)
print, n_elements(files)
cd, curdir[0]

files = files(1:n_elements(files) - 1)	;Strip first element- don't need it.

    ;;;; Check which version of headers and files we've got.
    ftmp = topdir + dataday + '/' + files(0)
    zzz = readfits(ftmp, fitshdr, noscale=1 , silent=0 )
    ydim   = sxpar(fitshdr,'NAXIS2')

    if( ydim ne 1030 ) then begin ;{
	oldheader=1
	exit
    endif $
    else begin ;}{
	oldheader=0
	lm_f_subs  = where(strpos(files, 'alr')  ne -1 ) ;Limb images
	lk_f_subs  = where(strpos(files, 'lowk') ne -1 ) ;lowk images
	ds_f_subs  = where(strpos(files, 'asr')  ne -1 ) ;Disk images
	;ds_f_subs  = where(strpos(files, 'asl')  ne -1 ) ;Disk images
	f1_f_subs  = where(strpos(files, 'afr')  ne -1 ) ;Diffuser-0.5A
	f2_f_subs  = where(strpos(files, 'xfr')  ne -1 ) ;Diffuser-10A
	lmd_f_subs = where(strpos(files, 'xbr')  ne -1 ) ;Limb darks
	lkd_f_subs = where(strpos(files, 'kbr')  ne -1 ) ;LOWK darks
	dsd_f_subs = where(strpos(files, 'abr')  ne -1 ) ;Disk darks
	fd1_f_subs = where(strpos(files, 'adr')  ne -1 ) ;diffuser (0.5A) darks
	fd2_f_subs = where(strpos(files, 'xdr')  ne -1 ) ;diffuser (10A) darks
    endelse    ;}

;If there are files of a certain type, then set up a string array of their
;names, and set up the logfile housekeeping stuff.

if lm_f_subs(0) ne -1 then begin
   limb_fnms = files(lm_f_subs)
   nm = n_elements(limb_fnms)
   lm_comments = strarr(nm)
   lm_done = intarr(nm)
   lm_qual = strarr(nm)
endif else begin
   lm_done = [1]
   limb_fnms = 'n'
   log_done(0) = 1
   lm_qual = ' '
   lm_comments = ' '
endelse

if ds_f_subs(0) ne -1 then begin
   disk_fnms = files(ds_f_subs)
   nm = n_elements(disk_fnms)
   ds_comments = strarr(nm)
   ds_done = intarr(nm)
   ds_qual = strarr(nm)
endif else begin
   ds_done = [1]
   disk_fnms = 'n'
   log_done(1) = 1
   ds_qual = ' '
   ds_comments = ' '
endelse

if lk_f_subs(0) ne -1 then begin
   lowk_fnms = files(lk_f_subs)
   nm = n_elements(lowk_fnms)
   lk_comments = strarr(nm)
   lk_done = intarr(nm)
   lk_qual = strarr(nm)
endif else begin
   lk_done = [1]
   lowk_fnms = 'n'
   log_done(2) = 1
   lk_qual = ' '
   lk_comments = ' '
endelse

if f1_f_subs(0) ne -1 then begin
   flat1_fnms = files(f1_f_subs)
   nm = n_elements(flat1_fnms)
   f1_comments = strarr(nm)
   f1_done = intarr(nm)
   f1_qual = strarr(nm)
endif else begin
   f1_done = [1]
   flat1_fnms = 'n'
   log_done(3) = 1
   f1_qual = ' '
   f1_comments = ' '
endelse

if f2_f_subs(0) ne -1 then begin
   flat2_fnms = files(f2_f_subs)
   nm = n_elements(flat2_fnms)
   f2_comments = strarr(nm)
   f2_done = intarr(nm)
   f2_qual = strarr(nm)
endif else begin
   f2_done = [1]
   flat2_fnms = 'n'
   log_done(4) = 1
   f2_qual = ' '
   f2_comments = ' '
endelse

if fd1_f_subs(0) ne -1 then begin
   diff1d_fnms = files(fd1_f_subs)
   nm = n_elements(diff1d_fnms)
   fd1_comments = strarr(nm)
   fd1_done = intarr(nm)
   fd1_qual = strarr(nm)
endif else begin
   fd1_done = [1]
   diff1d_fnms = 'n'
   log_done(5) = 1
   fd1_qual = ' '
   fd1_comments = ' '
endelse

if fd2_f_subs(0) ne -1 then begin
   diff2d_fnms = files(fd2_f_subs)
   nm = n_elements(diff2d_fnms)
   fd2_comments = strarr(nm)
   fd2_done = intarr(nm)
   fd2_qual = strarr(nm)
endif else begin
   fd2_done = [1]
   diff2d_fnms = 'n'
   log_done(6) = 1
   fd2_qual = ' '
   fd2_comments = ' '
endelse

if lmd_f_subs(0) ne -1 then begin
   limbd_fnms = files(lmd_f_subs)
   nm = n_elements(limbd_fnms)
   lmd_comments = strarr(nm)
   lmd_done = intarr(nm)
   lmd_qual = strarr(nm)
endif else begin
   lmd_done = [1]
   limbd_fnms = 'n'
   log_done(7) = 1
   lmd_qual = ' '
   lmd_comments = ' '
endelse

if dsd_f_subs(0) ne -1 then begin
   diskd_fnms = files(dsd_f_subs)
   nm = n_elements(diskd_fnms)
   dsd_comments = strarr(nm)
   dsd_done = intarr(nm)
   dsd_qual = strarr(nm)
endif else begin
   dsd_done = [1]
   diskd_fnms = 'n'
   log_done(8) = 1
   dsd_qual = ' '
   dsd_comments = ' '
endelse

if lkd_f_subs(0) ne -1 then begin
   lowkd_fnms = files(lkd_f_subs)
   nm = n_elements(lowkd_fnms)
   lkd_comments = strarr(nm)
   lkd_done = intarr(nm)
   lkd_qual = strarr(nm)
endif else begin
   lkd_done = [1]
   lowkd_fnms = 'n'
   log_done(9) = 1
   lkd_qual = ' '
   lkd_comments = ' '
endelse

;Finally, and this sucks, there's really no better way to get the start and
;stop time for the log files than to get it from the filenames.
if(oldheader eq 1) then spt=7 else spt=21

;;files_trim = files(where(strmid(files, 0, 1) eq '9'))
;;tm_str   = strmid(files_trim, 7, 6)
tm_str   = strmid(files, spt, 6)
hrs_str  = fix(strmid(tm_str, 0  , 2))
min_str  = fix(strmid(tm_str, 2  , 2))
sec_str  = fix(strmid(tm_str, 4  , 2))
rollover = where(hrs_str lt 10)	;A few lines to add 24 hrs to where
if rollover(0) ne -1 then begin	;      the clock goes past midnight.
   hrs_str(rollover) = hrs_str(rollover + 24)
endif

tm_vals = float(hrs_str + min_str/60. + sec_str/(60.*60.))
max_ix = (where(tm_vals eq max(tm_vals)))(0)
min_ix = (where(tm_vals eq min(tm_vals)))(0)

stop_time  =  strmid(tm_str(max_ix), 0, 2)+':'+strmid(tm_str(max_ix), 2, 2)
start_time =  strmid(tm_str(min_ix), 0, 2)+':'+strmid(tm_str(min_ix), 2, 2)

sav_comm = ' '

return
end


