;This procedure is intended for use as part of the PCIAS system.  This system
;has been developed by the HAO dPMon project to facilitate the initial
;quality assurance procedures required for new dPMon data.  Please make
;no changes to any of the files in this directory without first contacting
;dPMon personnel.
;
;   Questions regarding PCIAS should be directed to:
;
;			Ray Wrigley     FL2 3084  x1588
;			Alice Lecinski  FL2 3037  x1523
;
;   This module displays the next image of the type requested, loading
;   images of that type to RAM in reduced form - 511X342 rebinned.
;
pro pcias_load_images, val
@pcias_common

datain = 0			;Flag for use later.

;Clear out windows if already in use.
if pwin_inds(0) ne 0 then for v = 0, n_images-1 do wdelete, pwin_inds(v)

;Clear out header info widgets during load.
widget_control, obsdat, set_value =  ' '
widget_control, obstim, set_value = ' '
widget_control, nexpos, set_value = ' '
widget_control, solrad, set_value = ' '
widget_control, aptwhl, set_value = ' '
widget_control, daysfil, set_value = ' '
widget_control, filtwhl, set_value = ' '
widget_control, occwhl, set_value = ' '
widget_control, hotpix, set_value = ' '
widget_control, coldpix, set_value = ' '

if(not n_elements(im_array)) then  im_array=intarr(xsz,ysz)

case val of			;Get number of images of selected type.
   'LIMB' : begin
	       n_images = n_elements(limb_fnms)
	       fnms = limb_fnms
	    end
   'DISK' : begin
	       n_images = n_elements(disk_fnms)
	       fnms = disk_fnms
	    end
   'LOWK' : begin
	        n_images = n_elements(lowk_fnms)
	        fnms = lowk_fnms
	    end
   'DIFF1-0.5A' : begin
		   n_images = n_elements(flat1_fnms)
		   fnms = flat1_fnms
		end
   'DIFF2-10A' : begin
		   n_images = n_elements(flat2_fnms)
		   fnms = flat2_fnms
		end
   'DIFF1 DARK': begin
		   n_images = n_elements(diff1d_fnms)
		   fnms = diff1d_fnms
		end
   'DIFF2 DARK': begin
		   n_images = n_elements(diff2d_fnms)
		   fnms = diff2d_fnms
		end
   'LIMB DARK' : begin
		    n_images = n_elements(limbd_fnms)
		    fnms = limbd_fnms
		 end
   'DISK DARK' : begin
		    n_images = n_elements(diskd_fnms)
		    fnms = diskd_fnms
		 end
   'LOWK DARK' : begin
		    n_images = n_elements(lowkd_fnms)
		    fnms = lowkd_fnms
		 end
endcase

if strtrim(fnms(0), 2) eq 'n' then goto, NOFILE

hdrs = ' '		        ;Nucleus for fits header storage.
hot_pix  = intarr(n_images)	;Array to save maximum pixels in images.
cold_pix = intarr(n_images)	;Array to save minimum pixels in images.

info_set = strarr(n_images, 8)  ;Will hold optics positions
				;This used to be in pcias_parse_hdrs.pro

widget_control, totim, set_value = string(n_images)	;Inform user.
pwin_inds = intarr(n_images)	;Vector to hold pixwin indexes.

get_lun, lun

for t = 0, n_images - 1 do begin
   widget_control, usr_out1, set_value = 'Loading image ' + string(t)

   ftmp   = topdir + dataday + '/' + fnms(t)

   im_tmp = readfits(ftmp, fitshdr, noscale=1 , silent=0 )
    
   xdim  = sxpar(fitshdr,'NAXIS1')
   ydim  = sxpar(fitshdr,'NAXIS2')

   if( ydim eq 1029 ) then begin ;{   This is old dPmon data prior to
                                 ;    the ACOS header... (pre late april 1996)
	oldheader=1
        info_set(t,0) = strtrim(       sxpar(fitshdr, 'DATE-OBS'), 2)
        info_set(t,1) = strtrim(       sxpar(fitshdr, 'TIME-OBS'), 2)
        info_set(t,2) = strtrim(string(sxpar(fitshdr, 'NIMAVG' )), 2) ; nexpos
        info_set(t,3) = strtrim(string(sxpar(fitshdr, 'RSUN'   )), 2) ; solrad
        info_set(t,4) = strtrim(       sxpar(fitshdr, 'OPTPOS2' ), 2) ; aptwhl
        info_set(t,5) = strtrim(       sxpar(fitshdr, 'OPTPOS3' ), 2) ; daysfil
        info_set(t,6) = strtrim(string(sxpar(fitshdr, 'OPTPOS4')), 2) ; filtwhl
        info_set(t,7) = strtrim(       sxpar(fitshdr, 'OPTPOS5' ), 2) ; occwhl
	hot_pix (t)   = max(im_tmp(100:xdim-1-100,100:ydim-1-100))
	cold_pix(t)   = min(im_tmp(100:xdim-1-100,100:ydim-1-100))
   endif $
   else begin ;}{
	oldheader=0
	zzz = readfits(ftmp, extnhdr,noscale=1,exten_no=1,silent=0)
	info_set(t,0) = strtrim(       sxpar(extnhdr,'DATE-OBS'), 2)
	info_set(t,1) = strtrim(       sxpar(extnhdr,'TIME-OBS'), 2)
	info_set(t,2) = strtrim(string(sxpar(extnhdr,'NIMSUM')) , 2)
	info_set(t,3) = strtrim(string(sxpar(extnhdr,'RSUN'))   , 2)
	info_set(t,4) = strtrim(       sxpar(extnhdr,'OPTPOS11'), 2) ; aptwhl
	info_set(t,5) = strtrim(       sxpar(extnhdr,'OPTPOS00'), 2) ; daysfil
	info_set(t,6) = strtrim(       sxpar(extnhdr,'OPTPOS09'), 2) ; filtwhl
	info_set(t,7) = strtrim(       sxpar(extnhdr,'OPTPOS12'), 2) ; occwhl
	hot_pix (t)   = fix(sxpar(fitshdr,'DATAMAX'))
	cold_pix(t)   = fix(sxpar(fitshdr,'DATAMIN'))

   endelse ;}
   hdrs = [hdrs, fitshdr]	;Add to string holding all header info.


;	In the rebinning below, the top and bottom rows and the right column
;	of im_tmp is dropped in order to make the array dimensions even
;	multiples of three.  This is necessary for the rebin routine,
;	which requires the result array to have dimensions which are
;	factors or multiples of the original array.

   case val of;{
      'LIMB' : begin
		im_array=rebin(im_tmp(0:xsz*scl-1,0:ysz*scl-1),xsz,ysz)
               end
      'DISK' : begin
		;im_array=rebin(im_tmp(0:xsz*scl-1,0:ysz*scl-1),xsz,ysz)
		im_array=im_tmp
               end
      else:     im_array=rebin(im_tmp(0:xsz*scl-1,0:ysz*scl-1),xsz,ysz)
   endcase    ;}
   window, /free, xsize = xsz, ysize = ysz, /pixmap	;Create pixmap.
   pwin_inds(t) = !d.window			;Get pixmap index.
   wset, pwin_inds(t)				;Direct output to pixmap.

   case datascale of		;Write image to pixmap according to scaling.
      0 : begin
	     n_exp = sxpar(fitshdr,'NIMAVG')
	     if(n_exp eq 0) then n_exp = sxpar(fitshdr,'NIMSUM')
	     if(n_exp eq 0) then n_exp=1
	     ; im_array = im_array / (1. * n_exp)
	     ; mxi = fix((1.+ (max(im_array(100:xsz-100,100:ysz-100)))/50.)*50.)
	       mxi = fix((1.+ (max(im_array(100:xsz-100,100:ysz-100)))/10.)*10.)
	     if(val eq 'DISK') then mni=fix(mxi-0.65*mxi)  else mni=0
	     if(val eq 'DISK') then mxi=fix(mxi-0.15*mxi)  else mxi=mxi
	     print,mni,mxi
	     tv, bytscl(im_array,min=mni,max=mxi,top=231)
	  end
      1 : begin
	     tv, bytscl(im_array,min=cold_pix(t),max=hot_pix(t))
	  end
   endcase

   wset, plot_index1	;Set output to draw widget to quickly display image.
   device, copy = [0, 0, xsz, ysz, wxp, wyp, pwin_inds(t)]
   widget_control, curim, set_value = string(t)
endfor

datain = 1		;Flag to indicate data was loaded, used below.

free_lun, lun

;Set up time arrays for eventual reading of the time slider.
if(oldheader eq 1 ) then begin ;{
    ;; 95d023.190202.l.fits
    spt=7
endif else begin ;}{
    ;; mlso_dpmn_alr_96d151_172741.fts
    spt=21
endelse ;}

hrarr  = float(strmid(fnms, spt  , 2))
minarr = float(strmid(fnms, spt+2, 2))
secarr = float(strmid(fnms, spt+4, 2))

tmarr =      (hrarr + minarr/60. + secarr/(60.*60.)) $
	- min(hrarr + minarr/60. + secarr/(60.*60.))
tmarr = tmarr * (1000./max(tmarr))

wset, plot_index1		;Set output to draw widget.

NOFILE:
if datain ne 1 then begin
   widget_control, totim, set_value = ' '
   widget_control, usr_out1, set_value = 'No files of that type today.'
endif

return
end
