;This procedure is intended for use as part of the PCIAS system.  This system
;has been developed by the HAO dPMon project to facilitate the initial
;quality assurance procedures required for new dPMon data.  Please make
;no changes to any of the files in this directory without first contacting
;dPMon personnel.
;
;   Questions regarding PCIAS should be directed to:
;
;			Ray Wrigley     FL2 3084  x1588
;			Alice Lecinski  FL2 3037  x1523
;
;   When all the information for the logfile is in, control is handed to
;   this routine, which then organizes the various string arrays and 
;   writes the actual log file, storing it the predetermined directory.
;   Also, this routine writes the archived limb and disk data files to
;   their appropriate storage locations.
;
pro pcias_writelogs
@pcias_common

;Set up arrays to hold lines of log file related to individual images.
limb_strs = strarr(n_elements(limb_fnms))
disk_strs = strarr(n_elements(disk_fnms))
lowk_strs = strarr(n_elements(lowk_fnms))
flat1_strs = strarr(n_elements(flat1_fnms))
flat2_strs = strarr(n_elements(flat2_fnms))
diff1d_strs = strarr(n_elements(diff1d_fnms))
diff2d_strs = strarr(n_elements(diff2d_fnms))
limbd_strs = strarr(n_elements(limbd_fnms))
diskd_strs = strarr(n_elements(diskd_fnms))
lowkd_strs = strarr(n_elements(lowkd_fnms))

;Create filename/comment lines of logfile.
for a = 0, n_elements(limb_fnms) - 1 do begin
   limb_strs(a) = limb_fnms(a) + lm_qual(a) + lm_comments(a)
endfor

for a = 0, n_elements(disk_fnms) - 1 do begin
   disk_strs(a) = disk_fnms(a) + ds_qual(a) + ds_comments(a)
endfor

for a = 0, n_elements(lowk_fnms) - 1 do begin
   lowk_strs(a) = lowk_fnms(a) + lk_qual(a) + lk_comments(a)
endfor

for a = 0, n_elements(flat1_fnms) - 1 do begin
   flat1_strs(a) = flat1_fnms(a) + f1_qual(a) + f1_comments(a)
endfor

for a = 0, n_elements(flat2_fnms) - 1 do begin
   flat2_strs(a) = flat2_fnms(a) + f2_qual(a) + f1_comments(a)
endfor

for a = 0, n_elements(limbd_fnms) - 1 do begin
   limbd_strs(a) = limbd_fnms(a) + lmd_qual(a) + lmd_comments(a)
endfor

for a = 0, n_elements(diskd_fnms) - 1 do begin
   diskd_strs(a) = diskd_fnms(a) + dsd_qual(a) + dsd_comments(a)
endfor

for a = 0, n_elements(lowkd_fnms) - 1 do begin
   lowkd_strs(a) = lowkd_fnms(a) + lkd_qual(a) + lkd_comments(a)
endfor

for a = 0, n_elements(diff1d_fnms) - 1 do begin
   diff1d_strs(a) = diff1d_fnms(a) + fd1_qual(a) + fd1_comments(a)
endfor

for a = 0, n_elements(diff2d_fnms) - 1 do begin
   diff2d_strs(a) = diff2d_fnms(a) + fd2_qual(a) + fd2_comments(a)
endfor

fnm_comm_array = [limb_strs, ' ', disk_strs, ' ', lowk_strs, ' ', flat1_strs,$ 
	   ' ', flat2_strs, ' ',diff1d_strs,' ', diff2d_strs,$
	   ' ', limbd_strs, ' ',diskd_strs, ' ', lowkd_strs]
	   

;Yank out any n's which are artifacts of the absence of a file type.
if (where(strtrim(fnm_comm_array, 2) eq 'n'))(0) ne -1 then begin
   fnm_comm_array = fnm_comm_array(where(strtrim(fnm_comm_array, 2) ne 'n'))
endif

;Get the year of the image file and create the string for the path to save to.
endyr = strmid(dataday, 0, 2)
if fix(endyr) gt 78 then yr = '19' + endyr else yr = '20' + endyr
;path = '/jabba/ftp/dpm/log/' + yr
path = '/toshi/ftp/d5/dpm/log/' + yr

;Begin writing to output file.
get_lun, lun

tpfile = path + '/tmp.log'
lgfile = path + '/' + dataday + '.log'

openw,  lun, tpfile

printf, lun, transpose(fnm_comm_array)
printf, lun, ' '
printf, lun, 'Start time: ' + start_time
printf, lun, 'Stop time : ' + stop_time
printf, lun, ' '
printf, lun, 'Daily Summary : '
printf, lun, daily_summ
printf, lun, ' '
printf, lun, 'Limb Events : '
printf, lun, limb_events
printf, lun, ' '
printf, lun, 'Disk Events : '
printf, lun, disk_events
printf, lun, ' '
cur_time_str = strmid(!stime, 0, 12)
printf, lun, 'These notes recorded by ' + op_name + ', ' + cur_time_str
close, lun

;cmnd='cat '+tpfile+' >> '+lgfile
cmnd='cat '+tpfile+' > '+lgfile
spawn,cmnd
cmnd='/bin/rm '+tpfile
spawn,cmnd

;Make second copy of logfile in /puu/f/cordyn/DATA_BASE/pciasLogs
cp_str = 'cp ' + path + '/' + dataday + '.log'+' /puu/f/cordyn/DATA_BASE/pciasLogs/'+$
	dataday + '.log'
spawn, cp_str


;Generate month name from day of year, for use below.
year = fix(yr)
day = fix(strmid(dataday, 3, 3))

mons=['01_jan','02_feb','03_mar','04_apr','05_may','06_jun','07_jul','08_aug','09_sep','10_oct','11_nov','12_dec']

mon_dys = [[0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334],$
           [0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335]]

leap = ((year mod 4 eq 0) and (year mod 100 ne 0)) or (year mod 400 eq 0)

ix = where(day gt mon_dys(*, leap))
month = mons(max(ix))


;Copy an image an hour to /jabba/ftp/events
cmnd = 'rsh puu /home/cordyn/dPmon/bin/cp_hourly_pics '$
       + dataday + ' ' +topdir+' &'
spawn,cmnd

;Copy archive image files to final daily_images directory.
; That way the following is no longer needed:
;      remDmv aka mkDmv later puts them into the 
;     /jabba/ftp/dpm/daily_images/????/??_???
; directory

cp_cmd_lm = 'cp ' + topdir + dataday + '/' + lm_arch_fnm  +$
      ' /toshi/ftp/d5/dpm/daily_images/' + yr + '/' + month
;     ' /puu/ftpdpm/dpm_best'

cp_cmd_ds = 'cp ' + topdir + dataday + '/' + ds_arch_fnm  +$
      ' /toshi/ftp/d5/dpm/daily_images/' + yr + '/' + month
;     ' /puu/ftpdpm/dpm_best'


print,'Trying to copy limb archive image. ',cp_cmd_lm & spawn, cp_cmd_lm
print,'Trying to copy disk archive image. ',cp_cmd_ds & spawn, cp_cmd_ds

;;; Copy the right stuff to the 'band' directory.
;;; Get the minutes from the "ds_arch_fnm"

    ;;96d107.190046.d.fits
    ;;0123456789.12

if(oldheader eq 1 ) then begin ;{
    ;; 95d023.190202.d.fits
    spt=0
endif else begin ;}{
    ;; mlso_dpmn_alr_96d151_172741.fts
    spt=14
endelse ;}

    yrddoy=(strmid(ds_arch_fnm, spt+0, 7))
    hrs=fix(strmid(ds_arch_fnm, spt+7, 2))
    mns=fix(strmid(ds_arch_fnm, spt+9, 2))
    if ( mns gt 30 ) then hrs = hrs + 1
    hrss = strcompress(string(hrs),/remove_all)

    bdisk  = topdir + dataday + '/' +ds_arch_fnm
    if(oldheader eq 1 ) then begin ;{
	flatf  = topdir + dataday + '/' +yrddoy+hrss+'*.f.fits'
	limbdf = topdir + dataday + '/' +yrddoy+hrss+'*.ld.fits'
    endif else begin ;}{ 
	flatf  = topdir + dataday + '/' +'*adr_'+yrddoy+hrss+'*.fts'
	;limbdf = topdir + dataday + '/' +'*xbr_'+yrddoy+hrss+'*.fts'
	limbdf1 = topdir + dataday + '/' +'*abr_'+yrddoy+hrss+'*.fts'
	limbdf2 = topdir + dataday + '/' +'*afr_'+yrddoy+hrss+'*.fts'
    endelse ;}

    ;cp_cmd = 'cp '+bdisk+' '+flatf+' '+limbdf+' /toshi/ftp/d5/dpm/FlatPro'
cp_cmd='cp '+bdisk+' '+flatf+' '+limbdf1+' '+limbdf2+' /toshi/ftp/d5/dpm/FlatPro'
    spawn,cp_cmd

return
end
